@@ -12,7 +12,6 @@ import org.ovirt.engine.core.common.action.LockProperties;
 import org.ovirt.engine.core.common.businessentities.Provider;
 import org.ovirt.engine.core.common.businessentities.network.Network;
 import org.ovirt.engine.core.compat.Guid;
-import org.ovirt.engine.core.dao.VmDao;
 import org.ovirt.engine.core.dao.network.NetworkDao;
 import org.ovirt.engine.core.dao.provider.ProviderDao;
 import org.ovirt.engine.core.utils.transaction.TransactionSupport;
@@ -23,8 +22,6 @@ public class AddNetworkOnProviderCommand<T extends AddNetworkStoragePoolParamete
     @Inject
     private ProviderDao providerDao;
     @Inject
-    private VmDao vmDao;
-    @Inject
     private NetworkDao networkDao;
     @Inject
     private ProviderProxyFactory providerProxyFactory;
