@@ -3,7 +3,11 @@ package org.ovirt.engine.core.common.businessentities;
 import java.io.Serializable;
 
 public interface ExternalEntityBase extends Serializable {
-    public abstract String getDescription();
+    String getDescription();
 
-    public abstract String getName();
+    String getName();
+
+    default String getViewableName() {
+        return getName();
+    }
 }
